#!/bin/sh

set -eu

if [ "$(id -u)" != "0" ]; then
    echo "Need root for the mknod stuff :/"
    exit 1
fi

ARCH=amd64
RELEASE=xenial
FNAME=classic-${RELEASE}-${ARCH}.tar.xz

out="$(wget -O - "https://images.linuxcontainers.org/meta/1.0/index-system")"
dir="$(echo "$out" | grep "^ubuntu;$RELEASE;$ARCH;default" | cut -f6 -d';')"
url="https://images.linuxcontainers.org${dir}/rootfs.tar.xz"
wget -O $FNAME -c $url 

# cleanup
rm -rf unpack-classic


mkdir -p unpack-classic/classic-ro
# some point points we need
mkdir -p unpack-classic/classic-ro/var/lib/extrausers
mkdir -p unpack-classic/classic-ro/snappy

cd unpack-classic/classic-ro
# needs root for mknod
tar xf ../../$FNAME
cd ..

mkdir meta
cat > meta/package.yaml <<EOF
name: ubuntu-classic
version: $(date '+%Y.%m.%d')-1
architecture: $ARCH
vendor: Canonical

binaries:
 - name: bin/shell
   security-template: unconfined
 - name: bin/reset
   security-template: unconfined
EOF
cat > meta/readme.md <<EOF
The ubuntu-classic dimension
EOF

# the combined mount point
mkdir classic
mkdir bin

# the overlay script
cat > bin/shell <<'EOF'
#!/bin/sh
# enter classic ubuntu environment on snappy
# Author: Martin Pitt <martin.pitt@ubuntu.com>, Michael Vogt <mvo@ubuntu.com>

set -eu

# $1: source
# $2: target
# $3: if not empty, bind mount will be read-only
# note that we do NOT clean these up at the end, as the user might start many
# classic shells in parallel; we could start all of them in their own mount
# namespace, but that would make the classic shell less useful for
# developing/debugging the snappy host
do_bindmount() {
    if ! mountpoint -q "$ROOT/$2"; then
        if [ -d "$1" -a ! -L "$1" ]; then
            mkdir -p "$ROOT/$2"
        fi
        mount --make-rprivate --rbind -o rbind "$1" "$ROOT/$2"
        if [ -n "${3:-}" ]; then
            mount --rbind -o remount,ro "$1" "$ROOT/$2"
        fi
    fi
}

ROOT_RO=classic-ro
ROOT=classic

if [ "$(id -u)" != "0" ]; then
    echo "needs to run as root"
    exit 1
fi

if ! mountpoint -q "$ROOT"; then
  mount -t aufs -o br="${SNAP_APP_DATA_PATH}":"${ROOT_RO}" none "$ROOT"
fi

do_bindmount /home /home
do_bindmount /run /run
do_bindmount /proc /proc
do_bindmount /sys /sys
do_bindmount /dev /dev
do_bindmount /var/lib/extrausers /var/lib/extrausers "ro"
do_bindmount /etc/sudoers /etc/sudoers "ro"
do_bindmount /etc/sudoers.d /etc/sudoers.d "ro"
do_bindmount / /snappy

if [ -z "$SUDO_USER" ]; then
    echo "Cannot determine calling user, logging into classic as root"
    SUDO_USER=root
fi

systemd-run --quiet --scope --unit=snappy-classic.scope --description="Snappy Classic shell" chroot "$ROOT" sudo debian_chroot="classic" -u $SUDO_USER -i
# kill leftover processes after exiting, if it's still around
systemctl stop snappy-classic.scope || true
EOF
chmod +x bin/shell

# reset
cat > bin/reset <<'EOF'
#!/bin/sh
# reset the classic ubuntu environment

set -eu

ROOT=classic

if [ "$(id -u)" != "0" ]; then
    echo "needs to run as root"
    exit 1
fi

for d in /home /run /proc /sys /dev /var/lib/extrausers /etc/sudoers /etc/sudoers.d /snappy; do
  if mountpoint -q "$ROOT/$d"; then
    umount "$ROOT/$d"
  fi
done
if mountpoint -q "$ROOT"; then
  umount "$ROOT"
fi

if [ -z "${SNAP_APP_DATA_PATH}" ]; then
  rm -rf "${SNAP_APP_DATA_PATH}/*"
fi

EOF
chmod +x bin/reset

cd ..
# needs root for root owned files
snappy build --squashfs unpack-classic

