#!/bin/sh

set -e

#ARCH=amd64
#FNAME=xenial-preinstalled-core-$ARCH.device.tar.gz
ARCH=arm64
FNAME=xenial-preinstalled-core-$ARCH.device.tar.gz

wget -c http://cdimage.ubuntu.com/ubuntu-core/daily-preinstalled/current/$FNAME

rm -rf unpack-kernel-arm64
mkdir -p unpack-kernel-arm64
mkdir -p writable

cd unpack-kernel-arm64
tar xf ../$FNAME

# shuffle stuff around
mv system/* .
rmdir system

mv assets/* .
rmdir assets

# create meta
mkdir meta

# create symlinks so that uboot can eventually boot the kernel directly
kernel="$(ls vmlinuz-*)"
initrd="$(ls initrd.img-*)"
ln -s $kernel vmlinuz
ln -s $initrd initrd.img

cat > meta/readme.md <<EOF
The dragonboard kernel snap
EOF

cat > meta/package.yaml <<EOF
name: canonical-dragon-linux
version: 4.3.0-5-1
architecture: $ARCH
vendor: Canonical
type: kernel

kernel: $kernel
initrd: $initrd
modules: $(ls -d lib/modules/*)
firmware: lib/firmware
EOF
# dtbs
if [ -d dtbs ]; then
    printf "dtbs: dtbs/ \n" >> meta/package.yaml
fi


rm -f hardware.yaml

cd ..

# needs root for root owned files
fakeroot snappy build --squashfs unpack-kernel-arm64

