#!/bin/sh

set -e

modify_initrd() {
    rm -rf initramfs
    mkdir initramfs
    cd initramfs

    initrd=$(ls ../initrd.img-*)
    xzcat $initrd | cpio -i

    # FIXME2: add this to the kernel
    cp -a ../lib/modules/*/kernel/fs/squashfs lib/modules/*/kernel/fs/

    #mkdir -p lib/modules/*/kernel/fs/nls
    #cp -a ../lib/modules/*/kernel/fs/nls/*iso8859-1*.ko lib/modules/*/kernel/fs/nls

    find . | cpio --quiet -o -H newc | xz -c -9 --check=crc32 > $initrd
    
    cd ..
    rm -rf initramfs
}

ARCH=amd64
FNAME=xenial-preinstalled-core-$ARCH.device.tar.gz
VERSION="4.4.0-2-1"

wget -c http://cdimage.ubuntu.com/ubuntu-core/daily-preinstalled/current/$FNAME

rm -rf unpack-kernel
mkdir -p unpack-kernel
mkdir -p writable

cd unpack-kernel
tar xf ../$FNAME

# shuffle stuff around
mv system/* .
rmdir system

mv assets/* .
rmdir assets

# create meta
mkdir meta

# create symlinks so that grub can boot the kernel directly
kernel="$(ls vmlinuz-*)"
initrd="$(ls initrd.img-*)"
ln -s $kernel vmlinuz
ln -s $initrd initrd.img

# for compatiblity
cat > meta/readme.md <<EOF
The ubuntu-core kernel snap
EOF

cat > meta/package.yaml <<EOF
name: canonical-pc-linux
version: $VERSION
architecture: $ARCH
vendor: Canonical
type: kernel

kernel: $(ls vmlinuz-*)
initrd: $(ls initrd.img-*)
modules: $(ls -d lib/modules/*)
firmware: lib/firmware
EOF
# dtbs
if [ -d dtbs ]; then
    printf "dtbs: dtbs/ \n" >> meta/package.yaml
fi

# new snap.yaml
cat > meta/snap.yaml <<EOF
name: canonical-pc-linux
version: $VERSION
architectures: [$ARCH]
summary: The canonical amd64 kernel
type: kernel

kernel: $(ls vmlinuz-*)
initrd: $(ls initrd.img-*)
modules: $(ls -d lib/modules/*)
firmware: lib/firmware
EOF
# dtbs
if [ -d dtbs ]; then
    printf "dtbs: dtbs/ \n" >> meta/package.yaml
fi

rm -f hardware.yaml

cd ..

# needs root for root owned files
fakeroot snappy build --squashfs unpack-kernel

